;; Generated package description from simple-httpd.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "simple-httpd" "1.6.0.20260628.2" "Pure Elisp HTTP server" '((emacs "29.1") (compat "31")) :commit "e1c482700d2b32b09c16db3067c0a4958dd20c2a" :authors '(("Christopher Wellons" . "wellons@nullprogram.com")) :maintainer '(("Philip Kaludercic" . "philipk@posteo.net") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("network" "comm") :url "https://github.com/skeeto/emacs-http-server")
